Timeflux UI
===========

This plugin provides a framework to develop web applications that can interface with Timeflux. A monitoring web interface is bundled. It is not feature-complete yet, but it already allows you to visualize your data streams in real-time, in your browser, and to send events. Other examples include a SSVEP scheduler and a P300 speller. Both can be found in the ``apps`` directory.

Installation
------------

First, make sure that `Timeflux <https://github.com/timeflux/timeflux>`__ is installed.

You can then install this plugin in the `timeflux` environment:

::

    $ conda activate timeflux
    $ pip install timeflux_ui

Screenshot
----------

.. image:: https://github.com/timeflux/timeflux_ui/raw/master/doc/static/img/screenshot.png
